summaryrefslogtreecommitdiffstats
path: root/kmobile/devices
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/devices')
-rw-r--r--kmobile/devices/digicam/libkmobile_digicam.desktop2
-rw-r--r--kmobile/devices/gammu/libkmobile_gammu.desktop2
-rw-r--r--kmobile/devices/gnokii/gnokii_mobile.cpp62
-rw-r--r--kmobile/devices/gnokii/gnokii_mobile.h4
-rw-r--r--kmobile/devices/gnokii/gnokiiconfigui.ui2
-rw-r--r--kmobile/devices/gnokii/libkmobile_gnokii.desktop2
-rw-r--r--kmobile/devices/skeleton/libkmobile_skeleton.desktop2
-rw-r--r--kmobile/devices/skeleton/skeleton.cpp28
-rw-r--r--kmobile/devices/skeleton/skeleton.h4
9 files changed, 54 insertions, 54 deletions
diff --git a/kmobile/devices/digicam/libkmobile_digicam.desktop b/kmobile/devices/digicam/libkmobile_digicam.desktop
index 6e39cce6..adb3c9ab 100644
--- a/kmobile/devices/digicam/libkmobile_digicam.desktop
+++ b/kmobile/devices/digicam/libkmobile_digicam.desktop
@@ -107,6 +107,6 @@ Comment[uk]=Цей драйвер підтримує багато цифрови
Comment[zh_CN]=此驱动程序支持许多数码相机
Comment[zh_TW]=此驅動程式支援許多數位相機
Type=Service
-ServiceTypes=kdetqdevice/mobiletqdevice
+ServiceTypes=kdedevice/mobiledevice
X-KDE-Library=libkmobile_digicam
Icon=mobile_camera
diff --git a/kmobile/devices/gammu/libkmobile_gammu.desktop b/kmobile/devices/gammu/libkmobile_gammu.desktop
index daaa2372..f706b680 100644
--- a/kmobile/devices/gammu/libkmobile_gammu.desktop
+++ b/kmobile/devices/gammu/libkmobile_gammu.desktop
@@ -101,6 +101,6 @@ Comment[uk]=Цей драйвер підтримує багато мобільн
Comment[zh_CN]=此驱动程序通过 gammu 库支持许多诺基亚和其它移动电话
Comment[zh_TW]=此驅動程式支援許多 NOKIA 及其他手機,使用 gammu 函式庫
Type=Service
-ServiceTypes=kdetqdevice/mobiletqdevice
+ServiceTypes=kdedevice/mobiledevice
X-KDE-Library=libkmobile_gammu
Icon=mobile_phone
diff --git a/kmobile/devices/gnokii/gnokii_mobile.cpp b/kmobile/devices/gnokii/gnokii_mobile.cpp
index c4f31579..48c3b8ae 100644
--- a/kmobile/devices/gnokii/gnokii_mobile.cpp
+++ b/kmobile/devices/gnokii/gnokii_mobile.cpp
@@ -48,7 +48,7 @@
#define GNOKII_CHECK_ERROR(error) \
do { \
if (error) \
- PRINT_DEBUG << TQString("ERROR %1: %2\n").tqarg(error).tqarg(gn_error_print(error));\
+ PRINT_DEBUG << TQString("ERROR %1: %2\n").arg(error).arg(gn_error_print(error));\
} while (0)
@@ -74,16 +74,16 @@ static gn_calnote_list calnote_list;
/**
- * The KDE gnokii mobile tqdevice driver.
+ * The KDE gnokii mobile device driver.
*/
KMobileGnokii::KMobileGnokii(TQObject *obj, const char *name, const TQStringList &args )
: KMobileDevice(obj, name, args)
{
- // set initial tqdevice info
+ // set initial device info
setClassType( Phone );
- m_tqdeviceName = i18n("Mobile Phone accessed via GNOKII");
- m_tqdeviceRevision = "";
+ m_deviceName = i18n("Mobile Phone accessed via GNOKII");
+ m_deviceRevision = "";
m_connectionName = "/dev/ircomm0";
setCapabilities( hasAddressBook | hasNotes );
@@ -103,8 +103,8 @@ KMobileGnokii::KMobileGnokii(TQObject *obj, const char *name, const TQStringList
m_baud = "9600";
}
- PRINT_DEBUG << TQString("Using GNOKII configuration: %1 %2 %3 %4\n").tqarg(m_modelnr)
- .tqarg(m_connection).tqarg(m_port).tqarg(m_baud);
+ PRINT_DEBUG << TQString("Using GNOKII configuration: %1 %2 %3 %4\n").arg(m_modelnr)
+ .arg(m_connection).arg(m_port).arg(m_baud);
saveDeviceConfiguration();
saveGnokiiConfiguration();
@@ -148,7 +148,7 @@ bool KMobileGnokii::setGnokiiStateMachine()
{
// set the state machine to our configuration
qstrncpy( state.config.model, m_modelnr.utf8(), sizeof(state.config.model)-1 );
- qstrncpy( state.config.port_tqdevice, m_port.utf8(), sizeof(state.config.port_tqdevice)-1 );
+ qstrncpy( state.config.port_device, m_port.utf8(), sizeof(state.config.port_device)-1 );
state.config.connection_type = connectionToValue(m_connection);
state.config.serial_baudrate = m_baud.toUInt();
return true;
@@ -206,7 +206,7 @@ bool KMobileGnokii::loadDeviceConfiguration()
static void busterminate(void)
{
gn_sm_functions(GN_OP_Terminate, NULL, &state);
- if (lockfile) gn_tqdevice_unlock(lockfile);
+ if (lockfile) gn_device_unlock(lockfile);
}
static TQString businit(void)
@@ -222,7 +222,7 @@ static TQString businit(void)
aux = gn_cfg_get(gn_cfg_info, "global", "use_locking");
// Defaults to 'no'
if (aux && !strcmp(aux, "yes")) {
- lockfile = gn_tqdevice_lock(state.config.port_tqdevice);
+ lockfile = gn_device_lock(state.config.port_device);
if (lockfile == NULL) {
return i18n("Lock file error.\n "
"Please exit all other running instances of gnokii and try again.");
@@ -237,7 +237,7 @@ static TQString businit(void)
state.config.require_dcd = old_dcd;
if (error != GN_ERR_NONE) {
busterminate();
- return i18n("Mobile phone interface initialization failed:\n%1").tqarg(gn_error_print(error));
+ return i18n("Mobile phone interface initialization failed:\n%1").arg(gn_error_print(error));
}
// model
@@ -265,9 +265,9 @@ static TQString businit(void)
data.imei = NULL;
GNOKII_DEBUG( TQString("Found mobile phone: Model: %1, Revision: %2, IMEI: %3\n")
- .tqarg(model).tqarg(revision).tqarg(imei) );
+ .arg(model).arg(revision).arg(imei) );
- PhoneProductId = TQString("%1-%2-%3-%4").tqarg(APP).tqarg(model).tqarg(revision).tqarg(imei);
+ PhoneProductId = TQString("%1-%2-%3-%4").arg(APP).arg(model).arg(revision).arg(imei);
return TQString();
}
@@ -299,7 +299,7 @@ static gn_error read_phone_memstat( gn_memory_type memtype, gn_memory_status *me
}
}
GNOKII_DEBUG( TQString("\n\nMobile phone memory status: Type: %1, used=%2, free=%3, total=%4\n\n")
- .tqarg(memtype).tqarg(memstat->used).tqarg(memstat->free).tqarg(memstat->used+memstat->free) );
+ .arg(memtype).arg(memstat->used).arg(memstat->free).arg(memstat->used+memstat->free) );
return error;
}
@@ -372,8 +372,8 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
if (error != GN_ERR_NONE)
return error;
- GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").tqarg(index).tqarg(entry.name)
- .tqarg(entry.number).tqarg(entry.location).tqarg(entry.caller_group).tqarg(entry.subentries_count));
+ GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").arg(index).arg(entry.name)
+ .arg(entry.number).arg(entry.location).arg(entry.caller_group).arg(entry.subentries_count));
// try to split Name into FamilyName and GivenName
s = TQString(entry.name).simplifyWhiteSpace();
@@ -395,7 +395,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
}
a->insertCustom(APP, "X_GSM_CALLERGROUP", s.setNum(entry.caller_group));
- a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1_%2").tqarg(GN_MT_ME).tqarg(entry.location));
+ a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1_%2").arg(GN_MT_ME).arg(entry.location));
// set ProductId
a->setProductId(PhoneProductId);
@@ -407,7 +407,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
else
datetime = TQDateTime( TQDate(entry.date.year, entry.date.month, entry.date.day),
TQTime(entry.date.hour, entry.date.minute, entry.date.second) );
- GNOKII_DEBUG(TQString(" date=%1\n").tqarg(datetime.toString()));
+ GNOKII_DEBUG(TQString(" date=%1\n").arg(datetime.toString()));
a->setRevision(datetime);
if (!entry.subentries_count)
@@ -418,8 +418,8 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
for (int n=0; n<entry.subentries_count; n++) {
TQString s = TQString(entry.subentries[n].data.number).simplifyWhiteSpace();
GNOKII_DEBUG(TQString(" Subentry#%1, entry_type=%2, number_type=%3, number=%4\n")
- .tqarg(n).tqarg(entry.subentries[n].entry_type)
- .tqarg(entry.subentries[n].number_type).tqarg(s));
+ .arg(n).arg(entry.subentries[n].entry_type)
+ .arg(entry.subentries[n].number_type).arg(s));
if (s.isEmpty())
continue;
switch(entry.subentries[n].entry_type) {
@@ -478,7 +478,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
break;
default:
GNOKII_DEBUG(TQString(" Not handled id=%1, entry=%2\n")
- .tqarg(entry.subentries[n].entry_type).tqarg(s));
+ .arg(entry.subentries[n].entry_type).arg(s));
break;
} // switch()
} // for(subentry)
@@ -493,7 +493,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
-// connect the tqdevice and ask user to turn tqdevice on (if necessary)
+// connect the device and ask user to turn device on (if necessary)
bool KMobileGnokii::connectDevice(TQWidget * /*parent*/)
{
if (connected())
@@ -501,18 +501,18 @@ bool KMobileGnokii::connectDevice(TQWidget * /*parent*/)
TQString err = businit();
m_connected = err.isEmpty();
- PRINT_DEBUG << TQString("connectDevice() : %1\n").tqarg(m_connected ? "Ok" : err);
+ PRINT_DEBUG << TQString("connectDevice() : %1\n").arg(m_connected ? "Ok" : err);
return m_connected;
}
-// disconnect the tqdevice and return true, if sucessful
+// disconnect the device and return true, if sucessful
bool KMobileGnokii::disconnectDevice(TQWidget * /*parent*/)
{
if (!connected())
return true;
busterminate();
m_connected = false;
- PRINT_DEBUG << TQString("disconnectDevice() : %1\n").tqarg("done");
+ PRINT_DEBUG << TQString("disconnectDevice() : %1\n").arg("done");
return true;
}
@@ -545,9 +545,9 @@ TQString KMobileGnokii::iconFileName() const
// return a unique ID, e.g. the IMEI number of phones, or a serial number
// this String is used to have a unique identification for syncronisation.
-TQString KMobileGnokii::tqdeviceUniqueID()
+TQString KMobileGnokii::deviceUniqueID()
{
- return TQString("GNOKII-IMEI-%1").tqarg(TQString::fromLocal8Bit(imei));
+ return TQString("GNOKII-IMEI-%1").arg(TQString::fromLocal8Bit(imei));
}
@@ -587,7 +587,7 @@ int KMobileGnokii::numAddresses()
int KMobileGnokii::readAddress( int index, KABC::Addressee &addr )
{
- PRINT_DEBUG << TQString("############ GET ADDRESS #%1\n").tqarg(index);
+ PRINT_DEBUG << TQString("############ GET ADDRESS #%1\n").arg(index);
// index is zero-based, but in gnokii the first address starts at 1
if (index<0 || index>=numAddresses())
return KIO::ERR_DOES_NOT_EXIST;
@@ -609,7 +609,7 @@ int KMobileGnokii::readAddress( int index, KABC::Addressee &addr )
int KMobileGnokii::storeAddress( int, const KABC::Addressee &, bool )
{
- /* XXX: this is a read-only tqdevice */
+ /* XXX: this is a read-only device */
return KIO::ERR_WRITE_ACCESS_DENIED;
}
@@ -870,8 +870,8 @@ int KMobileGnokii::readNote( int index, TQString &note )
"DeviceClassName: %3\n"
"Device Driver : %4\n"
"Device Revision: %5\n")
- .tqarg(index).tqarg(index)
- .tqarg(tqdeviceClassName()).tqarg(tqdeviceName()).tqarg(revision());
+ .arg(index).arg(index)
+ .arg(deviceClassName()).arg(deviceName()).arg(revision());
return 0;
}
diff --git a/kmobile/devices/gnokii/gnokiiconfigui.ui b/kmobile/devices/gnokii/gnokiiconfigui.ui
index 255b6fb6..e7f6bb31 100644
--- a/kmobile/devices/gnokii/gnokiiconfigui.ui
+++ b/kmobile/devices/gnokii/gnokiiconfigui.ui
@@ -127,7 +127,7 @@
<cstring>textLabel2</cstring>
</property>
<property name="text">
- <string>Please configure your Gnokii mobile tqdevice</string>
+ <string>Please configure your Gnokii mobile device</string>
</property>
</widget>
<spacer row="2" column="0">
diff --git a/kmobile/devices/gnokii/libkmobile_gnokii.desktop b/kmobile/devices/gnokii/libkmobile_gnokii.desktop
index 986eded0..7e732ecd 100644
--- a/kmobile/devices/gnokii/libkmobile_gnokii.desktop
+++ b/kmobile/devices/gnokii/libkmobile_gnokii.desktop
@@ -101,6 +101,6 @@ Comment[uk]=Цей драйвер підтримує багато мобільн
Comment[zh_CN]=此驱动程序通过 gnokii 库支持许多诺基亚和其它移动电话
Comment[zh_TW]=此驅動程式支援許多 NOKIA 及其他手機,使用 gnokii 函式庫
Type=Service
-ServiceTypes=kdetqdevice/mobiletqdevice
+ServiceTypes=kdedevice/mobiledevice
X-KDE-Library=libkmobile_gnokii
Icon=mobile_phone
diff --git a/kmobile/devices/skeleton/libkmobile_skeleton.desktop b/kmobile/devices/skeleton/libkmobile_skeleton.desktop
index 2b22ca6e..72943d15 100644
--- a/kmobile/devices/skeleton/libkmobile_skeleton.desktop
+++ b/kmobile/devices/skeleton/libkmobile_skeleton.desktop
@@ -102,6 +102,6 @@ Comment[uk]=Прототип мобільного пристрою
Comment[zh_CN]=移动万能设备
Comment[zh_TW]=行動通訊空殼裝置
Type=Service
-ServiceTypes=kdetqdevice/mobiletqdevice
+ServiceTypes=kdedevice/mobiledevice
X-KDE-Library=libkmobile_skeleton
Icon=mobile_unknown
diff --git a/kmobile/devices/gnokii/gnokii_mobile.h b/kmobile/devices/gnokii/gnokii_mobile.h
index 96f32a5c..e3fe7bde 100644
--- a/kmobile/devices/gnokii/gnokii_mobile.h
+++ b/kmobile/devices/gnokii/gnokii_mobile.h
@@ -43,13 +43,13 @@ public:
bool connectDevice(TQWidget *parent);
bool disconnectDevice(TQWidget *parent);
// provide a tqdevice-specific configure dialog
bool configDialog(TQWidget *parent);
// filename and path to gnokii-icon
TQString iconFileName() const;
- TQString tqdeviceUniqueID();
+ TQString deviceUniqueID();
/*
* Addressbook / Phonebook support
@@ -43,13 +43,13 @@ public:
bool connectDevice(TQWidget *parent);
bool disconnectDevice(TQWidget *parent);
- // provide a tqdevice-specific configure dialog
+ // provide a device-specific configure dialog
bool configDialog(TQWidget *parent);
// filename and path to gnokii-icon
diff --git a/kmobile/devices/skeleton/skeleton.cpp b/kmobile/devices/skeleton/skeleton.cpp
index b5073de8..e6b1d9c5 100644
--- a/kmobile/devices/skeleton/skeleton.cpp
+++ b/kmobile/devices/skeleton/skeleton.cpp
@@ -43,16 +43,16 @@ TQObject *KMobileSkeleton::createObject( TQObject *parent, const char *name,
/**
* The KDE skeleton mobile tqdevice driver.
*/
KMobileSkeleton::KMobileSkeleton(TQObject *obj, const char *name, const TQStringList &args )
: KMobileDevice(obj, name, args)
{
// set initial tqdevice info
setClassType( Phone );
- m_tqdeviceName = i18n("LX-50-Moohoo Addressbook (Skeleton)");
- m_tqdeviceRevision = "0.1";
+ m_deviceName = i18n("LX-50-Moohoo Addressbook (Skeleton)");
+ m_deviceRevision = "0.1";
setCapabilities( hasAddressBook | hasNotes );
}
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
{
}
// connect the tqdevice and ask user to turn tqdevice on (if necessary)
bool KMobileSkeleton::connectDevice(TQWidget *parent)
{
if (KMessageBox::Continue != KMessageBox::warningContinueCancel(parent,
- i18n("Please turn on your %1 on now and press continue to proceed.").tqarg(m_tqdeviceName),
- m_tqdeviceClassName ) )
+ i18n("Please turn on your %1 on now and press continue to proceed.").arg(m_deviceName),
+ m_deviceClassName ) )
return false;
// connect it now...
m_connected = true;
return m_connected;
}
// disconnect the tqdevice and return true, if sucessful
bool KMobileSkeleton::disconnectDevice(TQWidget *)
{
m_connected = true;
return true;
}
// returns true, if this tqdevice is read-only (default: false)
bool KMobileSkeleton::isReadOnly() const
{
return true;
@@ -87,7 +87,7 @@ bool KMobileSkeleton::isReadOnly() const
// return a unique ID, e.g. the IMEI number of phones, or a serial number
// this String is used to have a unique identification for syncronisation.
-TQString KMobileSkeleton::tqdeviceUniqueID()
+TQString KMobileSkeleton::deviceUniqueID()
{
return TQString::fromLocal8Bit("SkElEtOn-123456789");
}
@@ -112,7 +112,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr )
return KIO::ERR_DOES_NOT_EXIST;
// now build our own sample name
- addr.setFamilyName(TQString("Meyer_%1").tqarg(index+1));
+ addr.setFamilyName(TQString("Meyer_%1").arg(index+1));
addr.setGivenName("Peter");
addr.setFormattedName("Peter "+addr.familyName());
addr.setNickName("PeterM");
@@ -132,7 +132,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr )
int KMobileSkeleton::storeAddress( int, const KABC::Addressee &, bool )
{
/* this is a read-only tqdevice */
return KIO::ERR_WRITE_ACCESS_DENIED;
}
@@ -156,8 +156,8 @@ int KMobileSkeleton::readNote( int index, TQString &note )
"DeviceClassName: %3\n"
"Device Driver : %4\n"
"Device Revision: %5\n")
- .tqarg(index).tqarg(index)
- .tqarg(tqdeviceClassName()).tqarg(tqdeviceName()).tqarg(revision());
+ .arg(index).arg(index)
+ .arg(deviceClassName()).arg(deviceName()).arg(revision());
return 0;
}
@@ -43,16 +43,16 @@ TQObject *KMobileSkeleton::createObject( TQObject *parent, const char *name,
/**
- * The KDE skeleton mobile tqdevice driver.
+ * The KDE skeleton mobile device driver.
*/
KMobileSkeleton::KMobileSkeleton(TQObject *obj, const char *name, const TQStringList &args )
@@ -43,16 +43,16 @@ TQObject *KMobileSkeleton::createObject( TQObject *parent, const char *name,
: KMobileDevice(obj, name, args)
{
- // set initial tqdevice info
+ // set initial device info
setClassType( Phone );
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
{
}
-// connect the tqdevice and ask user to turn tqdevice on (if necessary)
+// connect the device and ask user to turn device on (if necessary)
bool KMobileSkeleton::connectDevice(TQWidget *parent)
{
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
return m_connected;
}
-// disconnect the tqdevice and return true, if sucessful
+// disconnect the device and return true, if sucessful
bool KMobileSkeleton::disconnectDevice(TQWidget *)
{
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
return true;
}
-// returns true, if this tqdevice is read-only (default: false)
+// returns true, if this device is read-only (default: false)
bool KMobileSkeleton::isReadOnly() const
{
@@ -132,7 +132,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr )
int KMobileSkeleton::storeAddress( int, const KABC::Addressee &, bool )
{
- /* this is a read-only tqdevice */
+ /* this is a read-only device */
return KIO::ERR_WRITE_ACCESS_DENIED;
}
diff --git a/kmobile/devices/skeleton/skeleton.h b/kmobile/devices/skeleton/skeleton.h
index 6ae0287b..ab3ce770 100644
--- a/kmobile/devices/skeleton/skeleton.h
+++ b/kmobile/devices/skeleton/skeleton.h
@@ -42,14 +42,14 @@ public:
bool connectDevice(TQWidget *parent);
bool disconnectDevice(TQWidget *parent);
// returns true, if this tqdevice is read-only (default: false)
bool isReadOnly() const;
// you may provide your own icon() implementation to display
// an appropriate Pixmap (e.g. a Palm Pilot or a Zaurus image).
TQString iconFileName() const;
- TQString tqdeviceUniqueID();
+ TQString deviceUniqueID();
/*
* Addressbook / Phonebook support
@@ -42,14 +42,14 @@ public:
bool connectDevice(TQWidget *parent);
bool disconnectDevice(TQWidget *parent);
- // returns true, if this tqdevice is read-only (default: false)
+ // returns true, if this device is read-only (default: false)
bool isReadOnly() const;
// you may provide your own icon() implementation to display